@@ -2,14 +2,18 @@ from __future__ import division
 import os
 import pandas as pd
 import numpy as np
-from configparser import ConfigParser
+from configparser import ConfigParser, NoSectionError, NoOptionError
 import glob
-import cv2
+from simba.rw_dfs import *
 
 def ROItoFeatures(inifile):
     config = ConfigParser()
     config.read(inifile)
     noAnimals = config.getint('ROI settings', 'no_of_animals')
+    try:
+        wfileType = config.get('General settings', 'workflow_file_type')
+    except NoOptionError:
+        wfileType = 'csv'
     csv_dir = config.get('General settings', 'csv_path')
     csv_dir_in = os.path.join(csv_dir, 'features_extracted')
     vidInfPath = config.get('General settings', 'project_path')
@@ -50,7 +54,7 @@ def ROItoFeatures(inifile):
         else:
             return False, coord
 
-    filesFound = glob.glob(csv_dir_in + '/*.csv')
+    filesFound = glob.glob(csv_dir_in + '/*.' + wfileType)
     print('Extracting features from ' + str(len(filesFound)) + ' files...')
 
     for i in filesFound:
@@ -63,7 +67,7 @@ def ROItoFeatures(inifile):
         currPixPerMM = float(currVideoSettings['pixels/mm'])
         fps = float(currVideoSettings['fps'])
         currDfPath = os.path.join(csv_dir_in, CurrVidFn)
-        currDf = pd.read_csv(currDfPath)
+        currDf = read_df(currDfPath, wfileType)
         currDf = currDf.fillna(0)
         currDf = currDf.apply(pd.to_numeric)
         currDf = currDf.reset_index(drop=True)
@@ -230,6 +234,6 @@ def ROItoFeatures(inifile):
                 #     currDf[colName1, colName2] = currDf[colName1, colName2].round(2)
         currDf = currDf.fillna(0)
         currDf = currDf.replace(np.inf, 0)
-        currDf.to_csv(i)
+        save_df(currDf, wfileType, i)
         print('New feature file with ROI data saved: ' + str(r'project_folder\csv\features_extracted') + str(r'\\') + str(CurrVidFn))
     print('All ROI feature data appended to feature files.')
\ No newline at end of file
